@@ -5,7 +5,7 @@ import os
 import shutil
 import tempfile
 from pathlib import Path
-from typing import Dict, List
+from typing import Any, Dict, List
 
 import requests
 from deepchain import log
@@ -17,7 +17,8 @@ def upload_code(
     pat: str,
     url: str,
     score_configuration: List[str],
-) -> None:
+    app_visibility: bool,
+) -> Any:
     """Function to compress and upload code to google cloud bucket
 
     Args:
@@ -26,17 +27,17 @@ def upload_code(
         pat (str): personal token for uploading
         url (str): deployment URL
         score_configuration (List[str]): list of score names used in deepchain
-
+        app_visibility (bool): if this app will for private or public usage
     Returns:
         [type]: [description]
     """
     archive = shutil.make_archive(app_name, "tar", root_dir=app_dir + "/src")
-
     with open("scores.json", "w+") as config_file:
         json.dump(score_configuration, config_file)
     req = requests.post(
         url=url + app_name,
         headers={"authorisation": pat},
+        data={"public": app_visibility},
         files={
             "code": ("code.tar", open(archive, "rb"), "application/octet-stream"),
             "configuration": (
@@ -62,7 +63,7 @@ def upload_code(
     return req
 
 
-def upload_checkpoint(app_dir: str, app_name: str, pat: str, url: str, size_limit: int) -> None:
+def upload_checkpoint(app_dir: str, app_name: str, pat: str, url: str, size_limit: int) -> Any:
     """Tar checkpoints files and upload to deepchain
 
     Args:
@@ -75,7 +76,7 @@ def upload_checkpoint(app_dir: str, app_name: str, pat: str, url: str, size_limi
     Returns:
         [type]: [description]
     """
-    signed_url = get_object_storage_url(app_name, pat, url)
+    signed_url = get_object_storage_url(app_name, pat, url)  # type: ignore
 
     archive = shutil.make_archive(
         "checkpoint",
@@ -86,7 +87,7 @@ def upload_checkpoint(app_dir: str, app_name: str, pat: str, url: str, size_limi
         print(f"Can not upload files over {size_limit}MB")
     else:
         req = requests.put(
-            signed_url,
+            signed_url,  # type: ignore
             data=open(archive, "rb").read(),
             headers={"Content-Type": "application/octet-stream"},
         )
@@ -145,8 +146,15 @@ def unpack_base_repository(dest_path: str) -> None:
         dest_path (str]): path to copy the files
     """
     temp_dir = tempfile.mkdtemp()
-    shutil.unpack_archive(Path.home().joinpath(".deep-chain").joinpath("base.tar"),temp_dir)
+    shutil.unpack_archive(Path.home().joinpath(".deep-chain").joinpath("base.tar"), temp_dir)
     for file in glob.glob(rf"{temp_dir}/*/**", recursive=True):
         shutil.copytree(file, dest_path)
         break
 
+
+def get_app_visibility():
+    msg = "Do you want to make your app publicly available for usage and download ? (y/n) "
+    answer = input(msg)
+    while answer not in ["y", "n"]:
+        answer = input(msg)
+    return answer == "y"
