@@ -36,11 +36,7 @@ class TorchModel(pl.LightningModule):
         return torch.optim.Adam(self.parameters(), lr=self.lr)
 
     def fit(
-        self,
-        train_loader: DataLoader,
-        val_loader: DataLoader = None,
-        epochs: int = 10,
-        **kwargs
+        self, train_loader: DataLoader, val_loader: DataLoader = None, epochs: int = 10, **kwargs
     ):
         """Fit a model to data.
 
