@@ -9,20 +9,7 @@ from typing import List
 
 from deepchain import AppNotFoundError, CheckpointNotFoundError, log
 from deepchain.cli.apps_utils import get_app_info
-
-EXTENSIONS = [
-    ".h5",
-    ".hdf5",
-    ".yaml",
-    ".yml",
-    ".pt",
-    ".pb",
-    ".pkl",
-    ".ckpt",
-    ".pickle",
-]
-
-TAGS_KEY = ["tasks", "libraries", "embeddings", "datasets"]
+from deepchain.utils.constants import EXTENSIONS, TAGS_KEY
 
 
 def _check_checkpoint_files(app_name: str):
@@ -104,7 +91,6 @@ def _check_app(app_dir: Path) -> None:
         raise FileNotFoundError(message)
 
 
-
 def _check_json(app_dir: Path) -> bool:
     """Check if json file for tags if in the src folder"""
     tags_ok = True
@@ -128,12 +114,17 @@ def _check_json(app_dir: Path) -> bool:
         raise KeyError(message)
 
     for k, v in tags.items():
-        if not isinstance(v, list):
-            raise TypeError("The value of the json file should be of type list, even empty.")
+        if not isinstance(v, list) and k != "cuda":
+            raise TypeError(
+                "The value of the json file should be of type list, even empty, except for cuda."
+            )
         if k == "tasks":
             if len(v) == 0:
                 log.warning("Don't find any tasks in the tags.json file.")
                 tags_ok = False
+        elif k == "cuda":
+            if v[0] not in ["True", "False"]:
+                raise TypeError('The "cuda" tags only takes value in "True"/"False"')
 
     return tags_ok
 
